@@ -3,7 +3,7 @@ import contextlib
 import io
 import os
 import socket
-from typing import Dict, Optional
+from typing import Optional
 
 import aiohttp  # lgtm [py/import-and-import-from]
 from aiohttp import (
@@ -40,14 +40,16 @@ from botocore.httpsession import (
 from multidict import CIMultiDict
 
 import aiobotocore.awsrequest
-from aiobotocore._endpoint_helpers import _IOBaseWrapper, _text
+
+from ._constants import DEFAULT_KEEPALIVE_TIMEOUT
+from ._endpoint_helpers import _IOBaseWrapper, _text
 
 
 class AIOHTTPSession:
     def __init__(
         self,
         verify: bool = True,
-        proxies: Dict[str, str] = None,  # {scheme: url}
+        proxies: dict[str, str] = None,  # {scheme: url}
         timeout: float = None,
         max_pool_connections: int = MAX_POOL_CONNECTIONS,
         socket_options=None,
@@ -59,7 +61,7 @@ class AIOHTTPSession:
 
         # TODO: handle socket_options
         # keep track of sessions by proxy url (if any)
-        self._sessions: Dict[Optional[str], aiohttp.ClientSession] = {}
+        self._sessions: dict[Optional[str], aiohttp.ClientSession] = {}
         self._verify = verify
         self._proxy_config = ProxyConfiguration(
             proxies=proxies, proxies_settings=proxies_config
@@ -83,10 +85,9 @@ class AIOHTTPSession:
         self._timeout = timeout
         self._connector_args = connector_args
         if self._connector_args is None:
-            # AWS has a 20 second idle timeout:
-            #   https://web.archive.org/web/20150926192339/https://forums.aws.amazon.com/message.jspa?messageID=215367
-            # aiohttp default timeout is 30s so set something reasonable here
-            self._connector_args = dict(keepalive_timeout=12)
+            self._connector_args = dict(
+                keepalive_timeout=DEFAULT_KEEPALIVE_TIMEOUT
+            )
 
         self._max_pool_connections = max_pool_connections
         self._socket_options = socket_options
