@@ -1,11 +1,15 @@
-from botocore import UNSIGNED
+from botocore import UNSIGNED, translate
 from botocore import __version__ as botocore_version
-from botocore import translate
 from botocore.context import get_context
 from botocore.exceptions import PartialCredentialsError
-from botocore.session import EVENT_ALIASES, ServiceModel
+from botocore.session import (
+    EVENT_ALIASES,
+    ServiceModel,
+    UnknownServiceError,
+    copy,
+    logger,
+)
 from botocore.session import Session as _SyncSession
-from botocore.session import UnknownServiceError, copy, logger
 
 from . import __version__, retryhandler
 from .client import AioBaseClient, AioClientCreator
@@ -230,6 +234,7 @@ class AioSession(_SyncSession):
             exceptions_factory,
             config_store,
             user_agent_creator=user_agent_creator,
+            auth_token_resolver=self.get_auth_token,
         )
         client = await client_creator.create_client(
             service_name=service_name,
@@ -246,6 +251,7 @@ class AioSession(_SyncSession):
         monitor = self._get_internal_component('monitor')
         if monitor is not None:
             monitor.register(client.meta.events)
+        self._register_client_plugins(client)
         return client
 
     async def get_available_regions(
